==> libreoffice-libs-core-3.3.2.2.tar.bz2: libreoffice-libs-core-3.3.2.2/framework/source/classes/fwlresid.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_framework.hxx"

#include "classes/fwlresid.hxx"
#include <tools/string.hxx>
#include <osl/mutex.hxx>
#include <vcl/svapp.hxx>

#include <rtl/strbuf.hxx>

namespace framework
{

ResMgr*	FwlResId::GetResManager()
{
    static ResMgr*	pResMgr = NULL;
    
    if ( !pResMgr )
    {
        rtl::OStringBuffer aBuf( 32 );
        aBuf.append( "fwe" );
        
        SolarMutexGuard aSolarGuard;
        pResMgr = ResMgr::CreateResMgr( aBuf.getStr() );
    }
    
    return pResMgr;
}

// -----------------------------------------------------------------------

FwlResId::FwlResId( USHORT nId ) :
    ResId( nId, *FwlResId::GetResManager() )
{
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-libs-core-3.4.4.2.tar.bz2: libreoffice-libs-core-3.4.4.2/framework/source/classes/fwlresid.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

// MARKER(update_precomp.py): autogen include statement, do not remove
#include "precompiled_framework.hxx"

#include "classes/fwlresid.hxx"
#include <tools/string.hxx>
#include <osl/mutex.hxx>
#include <vcl/svapp.hxx>

#include <rtl/strbuf.hxx>

namespace framework
{

ResMgr*	FwlResId::GetResManager()
{
    static ResMgr*	pResMgr = NULL;
    
    if ( !pResMgr )
    {
        SolarMutexGuard aSolarGuard;
        pResMgr = ResMgr::CreateResMgr("fwe");
    }
    
    return pResMgr;
}

// -----------------------------------------------------------------------

FwlResId::FwlResId( sal_uInt16 nId ) :
    ResId( nId, *FwlResId::GetResManager() )
{
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
